function [tt xx dxx fo Last]=pendsolv(L,l,h,d,M,m,a,b,beta,g,T,tf,dt,xini)
%calling sequence:
%       [tt xx dxx fo Last]=pendsolv(L,l,h,d,M,m,a,b,beta,g,T,tf,dt,xini)
%
% Solves the pendulum system using a fourth order Runge-Kutta of fixed time
% step.
%
% Model parameters:
% a.	L: mass M length, [cm].
% b.	h: bar length, [cm].
% c.	l: length from axis point to bar bottom, [cm].
% d.	d: length from axis point to bar top, [cm].
% e.	M: mass of the bronze mass, [gr].
% f.	m: mass of the bar, [gr].
% g.	a: crank radius, [cm].
% h.	b: rod length.
% i.	beta: damping factor, [Nms].
% j.	g: gravity acceleration, [m/s^2]. In MKS g=9.81 m/s^2.
% k.	T: Excitation frequency, [seg].
% 
% Simulation parameters:
% a.	tf: Final simulation time, [seg].
% b.	dt: Time step, [seg].
% c.	xini: vector of length two for angle and velocity initial conditions. xini(1): angle, [degrees] and xini(2): velocity, [degrees/seg].
% 
% Output variables:
% a.	tt: Time instances. [sec]
% b.	xx: angle at each time instance, [degrees].
% c.	dxx: velocity at each time instance, [degrees/s].
% d.	fo: natural frequency for small amplitudes, [Hz].
% e.	Last: Equivalent length. [cm]


xini=xini*pi/180;

W=2*pi/T;


%bar intertia moment respect to the axis of rotation
I=m/3/h*(l^3+d^3);

%equivalent length scale.  Is the length of an ordinary pendulum of same
%oscilation frequency
Last=(I+M*L^2)/(M*L+m/2*(l-d));  %cm

%natural frequency
Wo=sqrt(g/(Last/100));
fo=Wo/2/pi;
To=1/fo;

fadim=1/2/pi*Wo/W;
beta_cap=beta/(I+M*L^2)*10000;
%params=[(Wo/W)^2 a/Last];
params=[Wo W a/Last beta_cap a b];


[tt xx]=rk42(@pendulum2,params,0,tf,xini,dt);

xx=xx*180/pi;

dxx=xx(:,2);
xx=xx(:,1);


